var TextLayer, btn, btnPrev, convertLocation, displayMapLayers, facetControl, facetControls, geojsonGaragesArray, geojsonSellPointsArray, geojsonTariffArray, getGeoCoordinates, initialize, j, len, locations, map, mapLayer, parkingmeters, ref, scroll, searchInput, setNewLocation, sketch, tariffControl, tariffareas, timeDayControl;

Framer.Info = {
  title: "Parkeertarieven v6",
  author: "Raymond Uphoff",
  twitter: "@myradon",
  description: "Prototype for City of Amsterdam to replace current implementation"
};

sketch = Framer.Importer.load("imported/ParkeertarievenToolv0.4FramerExport@2x");

locations = JSON.parse(Utils.domLoadDataSync("data/locations-v2.json"));

parkingmeters = JSON.parse(Utils.domLoadDataSync("data/verkooppunt.json"));

tariffareas = JSON.parse(Utils.domLoadDataSync("data/tarieven.json"));

TextLayer = require('TextLayer').TextLayer;

scroll = new ScrollComponent({
  width: Screen.width,
  height: Screen.height,
  backgroundColor: "#fff"
});

scroll.scrollHorizontal = false;

sketch.$1_Tablet_.superLayer = scroll.content;

mapLayer = new Layer({
  x: 0,
  y: 0,
  width: sketch.Maps.width,
  height: sketch.Maps.height,
  backgroundColor: "#fff",
  propagateEvents: false,
  superLayer: sketch.Maps
});

mapLayer.ignoreEvents = false;

mapLayer.classList.add("map");

document.getElementsByClassName("map")[0].setAttribute("id", "map");

tariffControl = sketch.tariff_control;

tariffControl.index = 101;

tariffControl.states = {
  hide: {
    x: 140,
    y: 415,
    opacity: 0,
    scale: 0.9,
    visible: false
  },
  show: {
    x: 197,
    y: 415,
    opacity: 1,
    scale: 1
  }
};

tariffControl.states.animationOptions = {
  curve: "ease-in-out",
  time: .25
};

tariffControl.stateSwitch("hide");

timeDayControl = sketch.time_days_control;

timeDayControl.index = 101;

timeDayControl.states = {
  hide: {
    x: 140,
    y: 429,
    opacity: 0,
    scale: 0.9,
    visible: false
  },
  show: {
    x: 197,
    y: 429,
    opacity: 1,
    scale: 1
  }
};

timeDayControl.states.animationOptions = {
  curve: "ease-in-out",
  time: .25
};

timeDayControl.stateSwitch("hide");

facetControls = {
  "btn_tariff": tariffControl,
  "btn_time": timeDayControl
};

btnPrev = void 0;

facetControl = function(btn) {
  return btn.on(Events.Tap, function(event, btn) {
    if (facetControls[btn.name].states.current.name === "hide") {
      facetControls[btn.name].visible = true;
      if (btnPrev !== void 0 && btnPrev !== btn) {
        facetControls[btnPrev.name].animate("hide");
      }
      btnPrev = btn;
    }
    return facetControls[btn.name].stateCycle("hide", "show");
  });
};

displayMapLayers = function(id) {
  var visibility;
  visibility = map.getLayoutProperty(id, "visibility");
  if (visibility === "visible") {
    return map.setLayoutProperty(id, "visibility", "none");
  } else {
    return map.setLayoutProperty(id, "visibility", "visible");
  }
};

sketch.btn_group.index = 100;

ref = sketch.btn_group.children;
for (j = 0, len = ref.length; j < len; j++) {
  btn = ref[j];
  if (btn.name === "btn_garage") {
    btn.on(Events.Tap, function(event, btn) {
      return displayMapLayers("garages");
    });
  }
  if (btn.name === "btn_parkingmeter") {
    btn.on(Events.Tap, function(event, btn) {
      return displayMapLayers("parkingmeters");
    });
  }
  if (btn.name === "btn_tariff") {
    facetControl(btn);
  }
  if (btn.name === "btn_time") {
    facetControl(btn);
  }
}

sketch._search.index = 100;

searchInput = new TextLayer({
  width: 660,
  autoSize: true,
  contentEditable: true,
  superLayer: sketch._search,
  text: "zoek op straatnaam of postcode",
  color: "#999",
  paddingTop: 30,
  paddingLeft: 40,
  paddingBottom: 30,
  paddingRight: 40,
  fontSize: 32,
  fontStyle: "italic"
});

searchInput.placeholderText = true;

sketch._search.on(Events.Tap, function(event) {
  if (searchInput.placeholderText === true) {
    searchInput.text = "";
    searchInput.fontStyle = "normal";
    searchInput.color = "#666";
    return searchInput.placeholderText = false;
  }
});

sketch._search.on("keypress", function(event) {
  var target;
  if (event.keyCode === 13) {
    event.preventDefault();
    target = searchInput.text;
    target = convertLocation(target);
    return getGeoCoordinates(target, setNewLocation);
  }
});

convertLocation = function(target) {
  var pattern;
  pattern = new RegExp(/^[1-9][0-9]{3} ?(?!sa|sd|ss)[a-z]{2}$/i);
  if (pattern.test(target)) {
    return target;
  } else {
    pattern = new RegExp(/(amsterdam)$/i);
    if (pattern.test(target)) {
      return target;
    } else {
      return target + " Amsterdam";
    }
  }
};

setNewLocation = function(location) {
  return map.flyTo({
    center: location.coordinates,
    zoom: 19,
    bearing: 5,
    speed: 0.75,
    curve: 2.5
  });
};

getGeoCoordinates = function(data, callback) {
  var result, url, xhr;
  data = data.replace(/\s/g, '+');
  url = "http://maps.google.com/maps/api/geocode/json?address=" + data + "&sensor=false";
  result = {
    coordinates: [],
    status: void 0
  };
  xhr = new XMLHttpRequest();
  xhr.open("GET", url);
  xhr.addEventListener("load", function() {
    var location;
    if (xhr.status === 200) {
      location = JSON.parse(xhr.responseText);
      if (location.results.length) {
        result.coordinates.push(location.results[0].geometry.location.lng, location.results[0].geometry.location.lat);
        result.status = location.status;
        return callback(result);
      } else {
        print("No results for typed location!");
        return result.states = "no results";
      }
    }
  });
  xhr.addEventListener("error", function() {
    print("error retrieving data with Maps-call");
    return result.status = "error";
  });
  return xhr.send();
};

geojsonGaragesArray = [];

geojsonSellPointsArray = [];

geojsonTariffArray = [];

(function() {
  var geoPoint, geolocation, k, len1, location, ref1, results;
  ref1 = locations.parkeerlocaties;
  results = [];
  for (k = 0, len1 = ref1.length; k < len1; k++) {
    location = ref1[k];
    geolocation = location.parkeerlocatie;
    geoPoint = {
      "type": "Feature",
      "geometry": JSON.parse(geolocation.Locatie),
      "properties": {
        "title": geolocation.title,
        "address": geolocation.adres,
        "postalcode": geolocation.postcode,
        "description": geolocation.opmerkingen,
        "url": geolocation.url,
        "type": geolocation.type
      }
    };
    results.push(geojsonGaragesArray.push(geoPoint));
  }
  return results;
})();

(function() {
  var geoPoint, k, len1, parkingmeter, ref1, results;
  ref1 = parkingmeters.features;
  results = [];
  for (k = 0, len1 = ref1.length; k < len1; k++) {
    parkingmeter = ref1[k];
    geoPoint = {
      "type": parkingmeter.type,
      "geometry": parkingmeter.geometry,
      "properties": {
        "title": parkingmeter.properties.VERKOOP_PU
      }
    };
    results.push(geojsonSellPointsArray.push(geoPoint));
  }
  return results;
})();

(function() {
  var area, areaKey, areaKeys, geoPoint, k, len1, results, setTarriff;
  areaKeys = Object.keys(tariffareas);
  results = [];
  for (k = 0, len1 = areaKeys.length; k < len1; k++) {
    areaKey = areaKeys[k];
    area = tariffareas[areaKey];
    setTarriff = function() {
      var bla, i, l, len2, number, size;
      size = Object.keys(area.tarieven).length;
      number = Object.keys(area.tarieven);
      bla = [];
      for (l = 0, len2 = number.length; l < len2; l++) {
        i = number[l];
        bla.push(area.tarieven[i]);
      }
      return {
        "amount": size,
        "tarrifs": bla
      };
    };
    console.log(setTarriff());
    geoPoint = {
      "type": "Feature",
      "geometry": {
        "type": "MultiPolygon",
        "coordinates": area.location.coordinates
      },
      "properties": {
        "title": area.description["0"]
      }
    };
    results.push(geojsonTariffArray.push(geoPoint));
  }
  return results;
})();

map = null;

initialize = function() {
  mapboxgl.accessToken = "pk.eyJ1IjoibXlyYWRvbiIsImEiOiJjaXhwdjJ0b2YwMDI1MzJvZnF1dGlncTE5In0.QyMS4Vd8C9klIWw0Rofj4w";
  map = new mapboxgl.Map({
    container: "map",
    style: "mapbox://styles/myradon/cixpv422u005o2rph0gmeawzv",
    center: [4.895168, 52.370216],
    zoom: 13,
    pitch: 25
  });
  return map.on("style.load", function(event) {
    map.addSource("garages", {
      type: "geojson",
      data: {
        type: "FeatureCollection",
        features: geojsonGaragesArray
      },
      cluster: true,
      clusterMaxZoom: 12,
      clusterRadius: 50
    });
    map.addSource("parkingmeters", {
      type: "geojson",
      data: {
        type: "FeatureCollection",
        features: geojsonSellPointsArray
      }
    });
    map.addSource("tariffareas", {
      type: "geojson",
      data: {
        type: "FeatureCollection",
        features: geojsonTariffArray
      }
    });
    map.addLayer({
      "id": "garages",
      "type": "symbol",
      "source": "garages",
      "layout": {
        "text-field": "{title}",
        "text-font": ["Open Sans Semibold"],
        "text-size": 24,
        "text-offset": [0, 0.5],
        "text-justify": "left",
        "text-anchor": "left"
      }
    });
    map.addLayer({
      "id": "parkingmeters",
      "type": "symbol",
      "source": "parkingmeters",
      "layout": {
        "text-field": "{title}",
        "text-font": ["Open Sans Regular"],
        "text-size": 16,
        "text-anchor": "center"
      }
    });
    return map.addLayer({
      "id": "tariffareas",
      "type": "fill",
      "source": "tariffareas",
      "paint": {
        "fill-color": "#ff0000",
        "fill-opacity": 0.3
      }
    });
  });
};

Utils.delay(0.1, function() {
  return initialize();
});
